pub struct Source(pub String);Expand description
The collection (e.g., album) or other source (e.g., a band website that hosts streams or audio files).
Tuple Fields
0: StringTrait Implementations
Sourceimpl AsXml for Source
impl AsXml for Source
impl Eq for Source
Sourceimpl FromXml for Source
impl FromXml for Source
Sourcefn from_events(
name: QName,
attrs: AttrMap,
ctx: &Context<'_>,
) -> Result<Self::Builder, FromEventsError>
fn from_events( name: QName, attrs: AttrMap, ctx: &Context<'_>, ) -> Result<Self::Builder, FromEventsError>
Attempt to initiate the streamed construction of this struct from XML. Read more
Sourcefn xml_name_matcher() -> XmlNameMatcher<'static>
fn xml_name_matcher() -> XmlNameMatcher<'static>
Return a predicate which determines if
Self may be parsed from
a given XML element. Read moreimpl StructuralPartialEq for Source