pub struct Track(pub String);Expand description
A unique identifier for the tune; e.g., the track number within a collection or the specific URI for the object (e.g., a stream or audio file).
Tuple Fields
0: StringTrait Implementations
Sourceimpl AsXml for Track
impl AsXml for Track
impl Eq for Track
Sourceimpl FromXml for Track
impl FromXml for Track
Sourcefn from_events(
name: QName,
attrs: AttrMap,
ctx: &Context<'_>,
) -> Result<Self::Builder, FromEventsError>
fn from_events( name: QName, attrs: AttrMap, ctx: &Context<'_>, ) -> Result<Self::Builder, FromEventsError>
Attempt to initiate the streamed construction of this struct from XML. Read more
Sourcefn xml_name_matcher() -> XmlNameMatcher<'static>
fn xml_name_matcher() -> XmlNameMatcher<'static>
Return a predicate which determines if
Self may be parsed from
a given XML element. Read moreimpl StructuralPartialEq for Track